==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/pa-Arab-PK.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    HHmmss => "HH:mm:ss",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "pa-Arab-PK",
  date_format_full => "EEEE, dd MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}"
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}"
  ],
  day_stand_alone_abbreviated => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}"
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}"
  ],
  era_abbreviated => [
    "\N{U+0627}\N{U+064a}\N{U+0633}\N{U+0627}\N{U+067e}\N{U+0648}\N{U+0631}\N{U+0648}",
    "\N{U+0633}\N{U+06ba}"
  ],
  era_narrow => [
    "\N{U+0627}\N{U+064a}\N{U+0633}\N{U+0627}\N{U+067e}\N{U+0648}\N{U+0631}\N{U+0648}",
    "\N{U+0633}\N{U+06ba}"
  ],
  era_wide => [
    "\N{U+0627}\N{U+064a}\N{U+0633}\N{U+0627}\N{U+067e}\N{U+0648}\N{U+0631}\N{U+0648}",
    "\N{U+0633}\N{U+06ba}"
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Punjabi",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}"
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}"
  ],
  name => "Punjabi Pakistan Arabic",
  native_language => "\N{U+067e}\N{U+0646}\N{U+062c}\N{U+0627}\N{U+0628}\N{U+06cc}",
  native_name => "\N{U+067e}\N{U+0646}\N{U+062c}\N{U+0627}\N{U+0628}\N{U+06cc} \N{U+067e}\N{U+0627}\N{U+06a9}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646} \N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
  native_script => "\N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
  native_territory => "\N{U+067e}\N{U+0627}\N{U+06a9}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}"
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}"
  ],
  script => "Arabic",
  territory => "Pakistan",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/pa-Arab-PK.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    HHmmss => "HH:mm:ss",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "pa-Arab-PK",
  date_format_full => "EEEE, dd MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "\N{U+067e}\N{U+06cc}\N{U+0631}",
    "\N{U+0645}\N{U+0646}\N{U+06af}\N{U+0644}",
    "\N{U+0628}\N{U+064f}\N{U+062f}\N{U+06be}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+0631}\N{U+0627}\N{U+062a}",
    "\N{U+062c}\N{U+0645}\N{U+0639}\N{U+06c1}",
    "\N{U+06c1}\N{U+0641}\N{U+062a}\N{U+06c1}",
    "\N{U+0627}\N{U+062a}\N{U+0648}\N{U+0627}\N{U+0631}",
  ],
  era_abbreviated => [
    "\N{U+0627}\N{U+064a}\N{U+0633}\N{U+0627}\N{U+067e}\N{U+0648}\N{U+0631}\N{U+0648}",
    "\N{U+0633}\N{U+06ba}",
  ],
  era_narrow => [
    "\N{U+0627}\N{U+064a}\N{U+0633}\N{U+0627}\N{U+067e}\N{U+0648}\N{U+0631}\N{U+0648}",
    "\N{U+0633}\N{U+06ba}",
  ],
  era_wide => [
    "\N{U+0627}\N{U+064a}\N{U+0633}\N{U+0627}\N{U+067e}\N{U+0648}\N{U+0631}\N{U+0648}",
    "\N{U+0633}\N{U+06ba}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Punjabi",
  month_format_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+062c}\N{U+0646}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0641}\N{U+0631}\N{U+0648}\N{U+0631}\N{U+06cc}",
    "\N{U+0645}\N{U+0627}\N{U+0631}\N{U+0686}",
    "\N{U+0627}\N{U+067e}\N{U+0631}\N{U+06cc}\N{U+0644}",
    "\N{U+0645}\N{U+0626}",
    "\N{U+062c}\N{U+0648}\N{U+0646}",
    "\N{U+062c}\N{U+0648}\N{U+0644}\N{U+0627}\N{U+0626}\N{U+06cc}",
    "\N{U+0627}\N{U+06af}\N{U+0633}\N{U+062a}",
    "\N{U+0633}\N{U+062a}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+0627}\N{U+06a9}\N{U+062a}\N{U+0648}\N{U+0628}\N{U+0631}",
    "\N{U+0646}\N{U+0648}\N{U+0645}\N{U+0628}\N{U+0631}",
    "\N{U+062f}\N{U+0633}\N{U+0645}\N{U+0628}\N{U+0631}",
  ],
  name => "Punjabi Pakistan Arabic",
  native_language => "\N{U+067e}\N{U+0646}\N{U+062c}\N{U+0627}\N{U+0628}\N{U+06cc}",
  native_name => "\N{U+067e}\N{U+0646}\N{U+062c}\N{U+0627}\N{U+0628}\N{U+06cc} \N{U+067e}\N{U+0627}\N{U+06a9}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646} \N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
  native_script => "\N{U+0639}\N{U+0631}\N{U+0628}\N{U+06cc}",
  native_territory => "\N{U+067e}\N{U+0627}\N{U+06a9}\N{U+0633}\N{U+062a}\N{U+0627}\N{U+0646}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+067e}\N{U+06c1}\N{U+0644}\N{U+0627}\N{U+06ba}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062f}\N{U+0648}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+062a}\N{U+064a}\N{U+062c}\N{U+0627}",
    "\N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}\N{U+064a} \N{U+0686}\N{U+0648}\N{U+062a}\N{U+06be}\N{U+0627}",
  ],
  script => "Arabic",
  territory => "Pakistan",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 35,
}
